@@ -4,7 +4,7 @@ import (
 	"encoding/base64"
 	"errors"
 
-	"github.com/go-acme/lego/v3/acme"
+	"github.com/go-acme/lego/v4/acme"
 )
 
 type OrderService service
@@ -25,28 +25,28 @@ func (o *OrderService) New(domains []string) (acme.ExtendedOrder, error) {
 	}
 
 	return acme.ExtendedOrder{
-		Location: resp.Header.Get("Location"),
 		Order:    order,
+		Location: resp.Header.Get("Location"),
 	}, nil
 }
 
 // Get Gets an order.
-func (o *OrderService) Get(orderURL string) (acme.Order, error) {
+func (o *OrderService) Get(orderURL string) (acme.ExtendedOrder, error) {
 	if len(orderURL) == 0 {
-		return acme.Order{}, errors.New("order[get]: empty URL")
+		return acme.ExtendedOrder{}, errors.New("order[get]: empty URL")
 	}
 
 	var order acme.Order
 	_, err := o.core.postAsGet(orderURL, &order)
 	if err != nil {
-		return acme.Order{}, err
+		return acme.ExtendedOrder{}, err
 	}
 
-	return order, nil
+	return acme.ExtendedOrder{Order: order}, nil
 }
 
 // UpdateForCSR Updates an order for a CSR.
-func (o *OrderService) UpdateForCSR(orderURL string, csr []byte) (acme.Order, error) {
+func (o *OrderService) UpdateForCSR(orderURL string, csr []byte) (acme.ExtendedOrder, error) {
 	csrMsg := acme.CSRMessage{
 		Csr: base64.RawURLEncoding.EncodeToString(csr),
 	}
@@ -54,12 +54,12 @@ func (o *OrderService) UpdateForCSR(orderURL string, csr []byte) (acme.Order, er
 	var order acme.Order
 	_, err := o.core.post(orderURL, csrMsg, &order)
 	if err != nil {
-		return acme.Order{}, err
+		return acme.ExtendedOrder{}, err
 	}
 
 	if order.Status == acme.StatusInvalid {
-		return acme.Order{}, order.Error
+		return acme.ExtendedOrder{}, order.Error
 	}
 
-	return order, nil
+	return acme.ExtendedOrder{Order: order}, nil
 }
