@@ -8,14 +8,12 @@ import (
 	"path/filepath"
 	"runtime"
 
-	"github.com/go-acme/lego/v3/cmd"
-	"github.com/go-acme/lego/v3/log"
+	"github.com/go-acme/lego/v4/cmd"
+	"github.com/go-acme/lego/v4/log"
 	"github.com/urfave/cli"
 )
 
-var (
-	version = "dev"
-)
+var version = "dev"
 
 func main() {
 	app := cli.NewApp()
@@ -29,11 +27,12 @@ func main() {
 		fmt.Printf("lego version %s %s/%s\n", c.App.Version, runtime.GOOS, runtime.GOARCH)
 	}
 
-	defaultPath := ""
+	var defaultPath string
 	cwd, err := os.Getwd()
 	if err == nil {
 		defaultPath = filepath.Join(cwd, ".lego")
 	}
+
 	app.Flags = cmd.CreateFlags(defaultPath)
 
 	app.Before = cmd.Before
