@@ -8,7 +8,7 @@ import (
 	"strings"
 )
 
-func (d *DNSProvider) doRequest(domain, value string, cmd string) error {
+func (d *DNSProvider) doRequest(domain, value, cmd string) error {
 	req, err := d.buildRequest(domain, value, cmd)
 	if err != nil {
 		return err
@@ -16,7 +16,7 @@ func (d *DNSProvider) doRequest(domain, value string, cmd string) error {
 
 	resp, err := d.config.HTTPClient.Do(req)
 	if err != nil {
-		return fmt.Errorf("error querying API: %v", err)
+		return fmt.Errorf("error querying API: %w", err)
 	}
 
 	defer resp.Body.Close()
@@ -34,7 +34,7 @@ func (d *DNSProvider) doRequest(domain, value string, cmd string) error {
 	return nil
 }
 
-func (d *DNSProvider) buildRequest(domain, value string, cmd string) (*http.Request, error) {
+func (d *DNSProvider) buildRequest(domain, value, cmd string) (*http.Request, error) {
 	params := url.Values{}
 	params.Set("CERTBOT_DOMAIN", domain)
 	params.Set("CERTBOT_VALIDATION", value)
@@ -42,7 +42,7 @@ func (d *DNSProvider) buildRequest(domain, value string, cmd string) (*http.Requ
 
 	req, err := http.NewRequest(http.MethodPost, defaultBaseURL, strings.NewReader(params.Encode()))
 	if err != nil {
-		return nil, fmt.Errorf("invalid request: %v", err)
+		return nil, fmt.Errorf("invalid request: %w", err)
 	}
 
 	req.Header.Set("Content-Type", "application/x-www-form-urlencoded")
