@@ -6,9 +6,9 @@ import (
 	"net/http"
 	"testing"
 
-	"github.com/go-acme/lego/v3/acme"
-	"github.com/go-acme/lego/v3/acme/api"
-	"github.com/go-acme/lego/v3/platform/tester"
+	"github.com/go-acme/lego/v4/acme"
+	"github.com/go-acme/lego/v4/acme/api"
+	"github.com/go-acme/lego/v4/platform/tester"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
@@ -18,14 +18,7 @@ func TestRegistrar_ResolveAccountByKey(t *testing.T) {
 	defer tearDown()
 
 	mux.HandleFunc("/account", func(w http.ResponseWriter, _ *http.Request) {
-		w.Header().Set("Location", apiURL+"/account_recovery")
-		_, err := w.Write([]byte("{}"))
-		if err != nil {
-			http.Error(w, err.Error(), http.StatusInternalServerError)
-		}
-	})
-
-	mux.HandleFunc("/account_recovery", func(w http.ResponseWriter, _ *http.Request) {
+		w.Header().Set("Location", apiURL+"/account")
 		err := tester.WriteJSONResponse(w, acme.Account{
 			Status: "valid",
 		})
